==> foundry_platform_sdk-0.80.0.tar.gz: foundry_platform_sdk-0.80.0/foundry/v2/core/errors/_invalid_page_token.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from dataclasses import dataclass
from typing import Literal

import pydantic
from typing_extensions import TypedDict

from foundry._errors import PalantirRPCException
from foundry.v2.core.models._page_token import PageToken


class InvalidPageTokenParameters(TypedDict):
    """The provided page token is invalid."""

    __pydantic_config__ = {"extra": "allow"}  # type: ignore

    pageToken: PageToken
    """
    The page token indicates where to start paging. This should be omitted from the first page's request.
    To fetch the next page, clients should take the value from the `nextPageToken` field of the previous response
    and use it to populate the `pageToken` field of the next request.
    """


@dataclass
class InvalidPageToken(PalantirRPCException):
    name: Literal["InvalidPageToken"]
    parameters: InvalidPageTokenParameters
    error_instance_id: str


__all__ = ["InvalidPageToken"]

==> foundry_platform_sdk-0.95.0.tar.gz: foundry_platform_sdk-0.95.0/foundry/v2/core/errors/_invalid_page_token.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from dataclasses import dataclass
from typing import Literal

from typing_extensions import TypedDict

from foundry._errors import BadRequestError
from foundry.v2.core.models._page_token import PageToken


class InvalidPageTokenParameters(TypedDict):
    """The provided page token is invalid."""

    __pydantic_config__ = {"extra": "allow"}  # type: ignore

    pageToken: PageToken
    """
    The page token indicates where to start paging. This should be omitted from the first page's request.
    To fetch the next page, clients should take the value from the `nextPageToken` field of the previous response
    and use it to populate the `pageToken` field of the next request.
    """


@dataclass
class InvalidPageToken(BadRequestError):
    name: Literal["InvalidPageToken"]
    parameters: InvalidPageTokenParameters
    error_instance_id: str


__all__ = ["InvalidPageToken"]
